@@ -1,7 +1,6 @@
 from decimal import Decimal
 
 class Lease:
-    MAB_MATURES_AFTER_BLOCKS = 86400
 
     def __init__(self, lease_id, address, amount, start_height, stop_height=None):
         self.lease_id = lease_id
@@ -17,14 +16,6 @@ class Lease:
 
         return self.stop_height is None or height < self.stop_height
 
-    def get_mab(self, height):
-        if not self.is_active(height):
-            return None
-
-        mab_modifier = Decimal(height - self.start_height) / Decimal(self.MAB_MATURES_AFTER_BLOCKS)
-        mab_modifier = min(1, mab_modifier)
-        return int(mab_modifier * self.amount)
-
     def add_minting_reward(self, minting_reward):
         self.total_interest += minting_reward.interest_for_lease(self)
 
